@@ -1,4 +1,3 @@
-import cgi
 import os
 from functools import partial
 from inspect import isawaitable
@@ -12,6 +11,14 @@ from starlette.datastructures import UploadFile
 from ...types import ContextValue, Extension, Resolver
 from .utils import format_path, should_trace
 
+try:
+    from multipart.multipart import File
+except ImportError:
+
+    class File:  # type: ignore
+        """Mock upload file used when python-multipart is not installed."""
+
+
 ArgFilter = Callable[[Dict[str, Any], GraphQLResolveInfo], Dict[str, Any]]
 
 
@@ -20,10 +27,9 @@ class OpenTracingExtension(Extension):
     _root_scope: Scope
     _tracer: Tracer
 
-    def __init__(self, *, arg_filter: Optional[ArgFilter] = None):
+    def __init__(self, *, arg_filter: Optional[ArgFilter] = None) -> None:
         self._arg_filter = arg_filter
         self._tracer = global_tracer()
-        self._root_scope = None
 
     def request_started(self, context: ContextValue):
         self._root_scope = self._tracer.start_active_span("GraphQL Query")
@@ -33,10 +39,10 @@ class OpenTracingExtension(Extension):
         self._root_scope.close()
 
     async def resolve(
-        self, next_: Resolver, parent: Any, info: GraphQLResolveInfo, **kwargs
+        self, next_: Resolver, obj: Any, info: GraphQLResolveInfo, **kwargs
     ):
         if not should_trace(info):
-            result = next_(parent, info, **kwargs)
+            result = next_(obj, info, **kwargs)
             if isawaitable(result):
                 result = await result
             return result
@@ -56,7 +62,7 @@ class OpenTracingExtension(Extension):
                 for kwarg, value in filtered_kwargs.items():
                     span.set_tag(f"graphql.param.{kwarg}", value)
 
-            result = next_(parent, info, **kwargs)
+            result = next_(obj, info, **kwargs)
             if isawaitable(result):
                 result = await result
             return result
@@ -74,10 +80,10 @@ class OpenTracingExtension(Extension):
 
 class OpenTracingExtensionSync(OpenTracingExtension):
     def resolve(
-        self, next_: Resolver, parent: Any, info: GraphQLResolveInfo, **kwargs
+        self, next_: Resolver, obj: Any, info: GraphQLResolveInfo, **kwargs
     ):  # pylint: disable=invalid-overridden-method
         if not should_trace(info):
-            result = next_(parent, info, **kwargs)
+            result = next_(obj, info, **kwargs)
             return result
 
         with self._tracer.start_active_span(info.field_name) as scope:
@@ -95,7 +101,7 @@ class OpenTracingExtensionSync(OpenTracingExtension):
                 for kwarg, value in filtered_kwargs.items():
                     span.set_tag(f"graphql.param.{kwarg}", value)
 
-            result = next_(parent, info, **kwargs)
+            result = next_(obj, info, **kwargs)
             return result
 
 
@@ -112,21 +118,24 @@ def copy_args_for_tracing(value: Any) -> Any:
         return {k: copy_args_for_tracing(v) for k, v in value.items()}
     if isinstance(value, list):
         return [copy_args_for_tracing(v) for v in value]
-    if isinstance(value, (UploadFile, cgi.FieldStorage)):
+    if isinstance(value, (UploadFile, File)):
         return repr_upload_file(value)
     return value
 
 
-def repr_upload_file(upload_file: Union[UploadFile, cgi.FieldStorage]) -> str:
-    filename = upload_file.filename
+def repr_upload_file(upload_file: Union[UploadFile, File]) -> str:
+    if isinstance(upload_file, File):
+        filename = upload_file.file_name
+    else:
+        filename = upload_file.filename
 
-    if isinstance(upload_file, cgi.FieldStorage):
-        mime_type = upload_file.type
+    if isinstance(upload_file, File):
+        mime_type = "not/available"
     else:
         mime_type = upload_file.content_type
 
-    if upload_file.file is None and isinstance(upload_file, cgi.FieldStorage):
-        size = len(upload_file.value) if upload_file.value is not None else 0
+    if isinstance(upload_file, File):
+        size = upload_file.size
     else:
         file_ = upload_file.file
         file_.seek(0, os.SEEK_END)
