@@ -27,6 +27,7 @@ from graphql.type.definition import (
     GraphQLInputField,
     GraphQLInputObjectType,
     GraphQLInputType,
+    GraphQLInterfaceType,
     GraphQLNonNull,
     GraphQLObjectType,
     GraphQLScalarType,
@@ -137,17 +138,16 @@ def find_enum_values_in_schema(
 
 @singledispatch
 def enum_values_in_types(
-    type_: Union[
-        GraphQLObjectType, GraphQLInputType
-    ],  # pylint: disable=unused-argument
+    type_: GraphQLNamedType,  # pylint: disable=unused-argument
     name: str,  # pylint: disable=unused-argument
 ) -> Optional[Generator[Union[ArgumentWithKeys, InputFieldWithKeys], None, None]]:
     pass
 
 
 @enum_values_in_types.register(GraphQLObjectType)
+@enum_values_in_types.register(GraphQLInterfaceType)
 def enum_values_in_object_type(
-    type_: GraphQLObjectType,
+    type_: Union[GraphQLObjectType, GraphQLInterfaceType],
     field_name: str,
 ) -> Generator[ArgumentWithKeys, None, None]:
     for field in type_.fields.values():
@@ -192,8 +192,7 @@ def _get_field_with_keys(field_name, fields):
 
 def get_enum_keys_from_ast(ast_node: InputValueDefinitionNode) -> List[List["str"]]:
     routes = []
-    object_node = ast_node.default_value
-    object_node = cast(ObjectValueNode, object_node)
+    object_node = cast(ObjectValueNode, ast_node.default_value)
     nodes = [([field.name.value], field) for field in object_node.fields]
 
     while nodes:
