@@ -1,10 +1,10 @@
-from .constants import HTTP_STATUS_400_BAD_REQUEST, HTTP_STATUS_405_METHOD_NOT_ALLOWED
+from .constants import HTTP_STATUS_400_BAD_REQUEST
 
 
 class HttpError(Exception):
     status = ""
 
-    def __init__(self, message=None):
+    def __init__(self, message=None) -> None:
         super().__init__()
         self.message = message
 
@@ -13,10 +13,6 @@ class HttpBadRequestError(HttpError):
     status = HTTP_STATUS_400_BAD_REQUEST
 
 
-class HttpMethodNotAllowedError(HttpError):
-    status = HTTP_STATUS_405_METHOD_NOT_ALLOWED
-
-
 class GraphQLFileSyntaxError(Exception):
     def __init__(self, schema_file, message) -> None:
         super().__init__()
