@@ -1,10 +1,10 @@
 from contextlib import contextmanager
-from typing import List, Optional, Type
+from typing import List, Optional
 
 from graphql import GraphQLError
 from graphql.execution import MiddlewareManager
 
-from .types import ContextValue, Extension
+from .types import ContextValue, ExtensionList
 
 
 class ExtensionManager:
@@ -12,9 +12,9 @@ class ExtensionManager:
 
     def __init__(
         self,
-        extensions: Optional[List[Type[Extension]]] = None,
-        context: ContextValue = None,
-    ):
+        extensions: Optional[ExtensionList] = None,
+        context: Optional[ContextValue] = None,
+    ) -> None:
         self.context = context
 
         if extensions:
