@@ -1,9 +1,10 @@
 import asyncio
 from collections.abc import Mapping
 from functools import wraps
-from typing import Optional, Union, Callable, Dict, Any
+from typing import Optional, Union, Callable, Dict, Any, cast
 
-from graphql import GraphQLError, parse
+from graphql.language import DocumentNode, OperationDefinitionNode, OperationType
+from graphql import GraphQLError, GraphQLType, parse
 
 
 def convert_camel_case_to_snake(graphql_name: str) -> str:
@@ -23,7 +24,7 @@ def convert_camel_case_to_snake(graphql_name: str) -> str:
             # TESTWord -> test_word
             or (
                 i < max_index
-                and graphql_name[i] != lowered_name[i]
+                and graphql_name[i] != c
                 and graphql_name[i + 1] == lowered_name[i + 1]
             )
             # test134 -> test_134
@@ -75,3 +76,27 @@ def convert_kwargs_to_snake_case(func: Callable) -> Callable:
         return func(*args, **convert_to_snake_case(kwargs))
 
     return wrapper
+
+
+def type_implements_interface(interface: str, graphql_type: GraphQLType) -> bool:
+    try:
+        return interface in [i.name for i in graphql_type.interfaces]  # type: ignore
+    except AttributeError:
+        pass
+
+    return False
+
+
+def get_operation_type(
+    graphql_document: DocumentNode, operation_name: Optional[str] = None
+) -> OperationType:
+    if operation_name:
+        for d in graphql_document.definitions:
+            d = cast(OperationDefinitionNode, d)
+            if d.name and d.name.value == operation_name:
+                return d.operation
+    else:
+        for definition in graphql_document.definitions:
+            if isinstance(definition, OperationDefinitionNode):
+                return definition.operation
+    raise RuntimeError("Can't get GraphQL operation type")
